@@ -1,5 +1,5 @@
 
-__version__ = "0.2.1"
+__version__ = "0.2.3"
 __common_alias__ = "nsitk"
 
 
@@ -55,5 +55,9 @@ from ._simpleitk_image_processing import \
     curvature_flow_denoise, \
     relabel_component, \
     label_contour, \
-    label_statistics
+    label_statistics, \
+    pixel_count_map, \
+    elongation_map, \
+    feret_diameter_map, \
+    roundness_map
 
